# hartmannActor

![Versions](https://img.shields.io/badge/python->=3.7-blue)
[![Test](https://github.com/sdss/hartmannActor/actions/workflows/test.yml/badge.svg)](https://github.com/sdss/hartmannActor/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/sdss/hartmannActor/branch/py3/graph/badge.svg)](https://codecov.io/gh/sdss/hartmannActor)

This commands the BOSS ICC to take Hartmann exposures, calculates the focus of the exposures, and if needed informs BOSS ICC to apply focus corrections to the collimator, and also the blue ring.
